==> render_html-1.0.0.tar.gz: render_html-1.0.0/tests/test_render_html.py <==
import unittest
from unittest.mock import patch, MagicMock

from src.render_html.exceptions import BrowserNotFoundException
from src.render_html._renderer import (
    render_in_browser,
    _handle_open_from_regular_file,
    _handle_open_from_temp,
)


class RendererTestCase(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
        cls.html_string = "<html><body><h1>Hello, World!</h1></body></html>"
        cls.save_path = "/path/to/save/file.html"
        cls.temp_path = "/path/to/temp/file.html"

    def test_handle_open_from_regular_file(self):
        with patch("builtins.open", create=True) as mock_open, patch(
            "webbrowser.open_new"
        ) as mock_webbrowser_open:
            mock_file = MagicMock()
            mock_file.name = self.save_path
            mock_open.return_value.__enter__.return_value = mock_file
            _handle_open_from_regular_file(self.html_string, self.save_path)
            mock_open.assert_called_once_with(self.save_path, "w")
            mock_file.write.assert_called_once_with(self.html_string)
            mock_webbrowser_open.assert_called_once_with(f"file:///{mock_file.name}")

    def test_handle_open_from_temp(self):
        with patch("tempfile.NamedTemporaryFile", create=True) as mock_tempfile, patch(
            "webbrowser.open_new"
        ) as mock_webbrowser_open:
            mock_file = MagicMock()
            mock_tempfile.return_value.__enter__.return_value = mock_file
            mock_file.name = self.temp_path
            _handle_open_from_temp(self.html_string)
            mock_tempfile.assert_called_once_with(mode="w", delete=True, suffix=".html")
            mock_file.write.assert_called_once_with(self.html_string)
            mock_webbrowser_open.assert_called_once_with(f"file:///{mock_file.name}")

    def test_render_in_browser_save_path(self):
        with patch("builtins.open", create=True) as mock_open, patch(
            "webbrowser.open_new"
        ) as mock_webbrowser_open:
            mock_file = MagicMock()
            mock_file.name = self.save_path
            mock_open.return_value.__enter__.return_value = mock_file
            render_in_browser(self.html_string, save_path=self.save_path)
            mock_open.assert_called_once_with(self.save_path, "w")
            mock_file.write.assert_called_once_with(self.html_string)
            mock_webbrowser_open.assert_called_once_with(f"file:///{mock_file.name}")

    def test_render_in_browser_temp_file(self):
        with patch("tempfile.NamedTemporaryFile", create=True) as mock_tempfile, patch(
            "webbrowser.open_new"
        ) as mock_webbrowser_open:
            mock_file = MagicMock()
            mock_tempfile.return_value.__enter__.return_value = mock_file
            mock_file.name = self.temp_path
            render_in_browser(self.html_string)
            mock_tempfile.assert_called_once_with(mode="w", delete=True, suffix=".html")
            mock_file.write.assert_called_once_with(self.html_string)
            mock_webbrowser_open.assert_called_once_with(f"file:///{mock_file.name}")

    def test_render_in_browser_browser_not_found(self):
        with patch("tempfile.NamedTemporaryFile", create=False):
            with self.assertRaises(BrowserNotFoundException):
                render_in_browser(self.html_string, browser="invalid_browser")


if __name__ == "__main__":
    unittest.main()

==> render_html_v2-1.0.0.tar.gz: render_html_v2-1.0.0/tests/test_render_html.py <==
import unittest
from unittest.mock import patch, MagicMock

from src.render_html.exceptions import BrowserNotFoundException
from src.render_html._renderer import (
    render_in_browser,
    _handle_open_from_regular_file,
    _handle_open_from_temp,
)


class RendererTestCase(unittest.TestCase):
    @classmethod
    def setUpClass(cls):
        cls.html_string = "<html><body><h1>Hello, World!</h1></body></html>"
        cls.save_path = "/path/to/save/file.html"
        cls.temp_path = "/path/to/temp/file.html"
        cls.selected_encoding = "utf-8"

    def test_handle_open_from_regular_file_default_encoding(self):
        with patch("builtins.open", create=True) as mock_open, patch(
            "webbrowser.open_new"
        ) as mock_webbrowser_open:
            mock_file = MagicMock()
            mock_file.name = self.save_path
            mock_open.return_value.__enter__.return_value = mock_file
            _handle_open_from_regular_file(self.html_string, self.save_path)
            mock_open.assert_called_once_with(self.save_path, "w", encoding = None)
            mock_file.write.assert_called_once_with(self.html_string)
            mock_webbrowser_open.assert_called_once_with(f"file:///{mock_file.name}")

    
    def test_handle_open_from_regular_file_selected_encoding(self):
        with patch("builtins.open", create=True) as mock_open, patch(
            "webbrowser.open_new"
        ) as mock_webbrowser_open:
            mock_file = MagicMock()
            mock_file.name = self.save_path
            mock_open.return_value.__enter__.return_value = mock_file
            _handle_open_from_regular_file(self.html_string, self.save_path, encoding = self.selected_encoding)
            mock_open.assert_called_once_with(self.save_path, "w", encoding = self.selected_encoding)
            mock_file.write.assert_called_once_with(self.html_string)
            mock_webbrowser_open.assert_called_once_with(f"file:///{mock_file.name}")


    def test_handle_open_from_temp_default_encoding(self):
        with patch("tempfile.NamedTemporaryFile", create=True) as mock_tempfile, patch(
            "webbrowser.open_new"
        ) as mock_webbrowser_open:
            mock_file = MagicMock()
            mock_tempfile.return_value.__enter__.return_value = mock_file
            mock_file.name = self.temp_path
            _handle_open_from_temp(self.html_string)
            mock_tempfile.assert_called_once_with(mode="w", delete=True, suffix=".html", encoding = None)
            mock_file.write.assert_called_once_with(self.html_string)
            mock_webbrowser_open.assert_called_once_with(f"file:///{mock_file.name}")


    def test_handle_open_from_temp_selected_encoding(self):
        with patch("tempfile.NamedTemporaryFile", create=True) as mock_tempfile, patch(
            "webbrowser.open_new"
        ) as mock_webbrowser_open:
            mock_file = MagicMock()
            mock_tempfile.return_value.__enter__.return_value = mock_file
            mock_file.name = self.temp_path
            _handle_open_from_temp(self.html_string, encoding = self.selected_encoding)
            mock_tempfile.assert_called_once_with(mode="w", delete=True, suffix=".html", encoding = self.selected_encoding)
            mock_file.write.assert_called_once_with(self.html_string)
            mock_webbrowser_open.assert_called_once_with(f"file:///{mock_file.name}")

    def test_render_in_browser_save_path_default_encoding(self):
        with patch("builtins.open", create=True) as mock_open, patch(
            "webbrowser.open_new"
        ) as mock_webbrowser_open:
            mock_file = MagicMock()
            mock_file.name = self.save_path
            mock_open.return_value.__enter__.return_value = mock_file
            render_in_browser(self.html_string, save_path=self.save_path)
            mock_open.assert_called_once_with(self.save_path, "w", encoding = None)
            mock_file.write.assert_called_once_with(self.html_string)
            mock_webbrowser_open.assert_called_once_with(f"file:///{mock_file.name}")


    def test_render_in_browser_save_path_selected_encoding(self):
        with patch("builtins.open", create=True) as mock_open, patch(
            "webbrowser.open_new"
        ) as mock_webbrowser_open:
            mock_file = MagicMock()
            mock_file.name = self.save_path
            mock_open.return_value.__enter__.return_value = mock_file
            render_in_browser(self.html_string, save_path=self.save_path, encoding=self.selected_encoding)
            mock_open.assert_called_once_with(self.save_path, "w", encoding = self.selected_encoding)
            mock_file.write.assert_called_once_with(self.html_string)
            mock_webbrowser_open.assert_called_once_with(f"file:///{mock_file.name}")

    def test_render_in_browser_temp_file_default_encoding(self):
        with patch("tempfile.NamedTemporaryFile", create=True) as mock_tempfile, patch(
            "webbrowser.open_new"
        ) as mock_webbrowser_open:
            mock_file = MagicMock()
            mock_tempfile.return_value.__enter__.return_value = mock_file
            mock_file.name = self.temp_path
            render_in_browser(self.html_string)
            mock_tempfile.assert_called_once_with(mode="w", delete=True, suffix=".html", encoding = None)
            mock_file.write.assert_called_once_with(self.html_string)
            mock_webbrowser_open.assert_called_once_with(f"file:///{mock_file.name}")


    def test_render_in_browser_temp_file_selected_encoding(self):
        with patch("tempfile.NamedTemporaryFile", create=True) as mock_tempfile, patch(
            "webbrowser.open_new"
        ) as mock_webbrowser_open:
            mock_file = MagicMock()
            mock_tempfile.return_value.__enter__.return_value = mock_file
            mock_file.name = self.temp_path
            render_in_browser(self.html_string, encoding=self.selected_encoding)
            mock_tempfile.assert_called_once_with(mode="w", delete=True, suffix=".html", encoding = self.selected_encoding)
            mock_file.write.assert_called_once_with(self.html_string)
            mock_webbrowser_open.assert_called_once_with(f"file:///{mock_file.name}")

    def test_render_in_browser_browser_not_found(self):
        with patch("tempfile.NamedTemporaryFile", create=False):
            with self.assertRaises(BrowserNotFoundException):
                render_in_browser(self.html_string, browser="invalid_browser")


if __name__ == "__main__":
    unittest.main()
